@@ -9,14 +9,9 @@ use IO::Socket::SSL;
 use REST::Client;
 use Carp;
 use JSON::XS;
-
-#use LWP; # This for setting up the user agent by hand, which apparently
-# we need in order to do proper hostname validation. Why? Seems that
-# REST::Client is geared up for using the Net::SSL backend for some
-# reason. Hey ho.
 use URI;    # The GET requests need URI-escaping
 
-our $VERSION = '0.00';
+our $VERSION = '0.02_01';
 
 sub new {
 	my ($class, %opts) = @_;
@@ -146,21 +141,17 @@ __END__
 
 =head1 NAME
 
-WebService::AbuseIPDB - Client for the API (version 2) of AbuseIPDB 
-
-=head1 VERSION
-
-Version 0.00
+WebService::AbuseIPDB - Client for the API (version 2) of AbuseIPDB
 
 =head1 SYNOPSIS
 
     use WebService::AbuseIPDB;
 
     my $ipdb = WebService::AbuseIPDB->new (key => 'abc123...');
-	my $res = $ipdb->check (ip => '127.0.0.2');
-	die unless defined $res;
-	printf "There is a %i%% chance this address is up to no good.\n",
-		$res->score;
+    my $res = $ipdb->check (ip => '127.0.0.2');
+    die unless defined $res;
+    printf "There is a %i%% chance this address is up to no good.\n",
+        $res->score;
 
 =head1 DESCRIPTION
 
@@ -176,7 +167,7 @@ as a client for Version 2 of the API.
 
 	my $ipdb = WebService::AbuseIPDB->new (%opts);
 
-The constructor takes a hash of configuration details. 
+The constructor takes a hash of configuration details.
 
 =over
 
@@ -231,11 +222,11 @@ B<Not yet impelemented>.
 
 =head2 report
 
-	my $res = $ipdb->report (
-		ip => '127.0.0.2',
-		categories => [3, 4],
-		comment => 'This address is the worst'
-	);
+    my $res = $ipdb->report (
+        ip          => '127.0.0.2',
+        categories  => [3, 4],
+        comment     => 'This address is the worst'
+    );
 
 This uses the C<report> endpoint to report an abusive address. It takes a
 single hash as the only argument with these elements:
@@ -292,8 +283,7 @@ Pete Houston, C<< <cpan at openstrike.co.uk> >>
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-webservice-abuseipdb at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebService-AbuseIPDB>.  See the file CONTRIBUTING.md for further details.
 
 =head1 ACKNOWLEDGEMENTS
 
